/**
  *  \file client/playvcrbg.h
  *  \brief PlayVCR Background Widget
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_PLAYVCRBG_H
#define PCC_V2_CLIENT_PLAYVCRBG_H

#include "client/widgets/imagepanel.h"
#include "cpluslib/holder.h"

/** PlayVCR background window. This acts as the container or
    background window for PlayVCR's main selection UI. It contains a
    nice background image as well as buttons for global options.

    Descendants must override the onSimulate() method which behaves
    differently whether we are in the game chooser or have a VCR file
    open. */
class WVcrBackgroundWindow : public WImagePanel {
    ObjectHolder h;

    void init();
 public:
    WVcrBackgroundWindow();
    ~WVcrBackgroundWindow();

    bool handleEvent(const UIEvent& event, bool second_pass);

    void onSoundConfig();
    void onGeneralConfig();
    void onConsole();

    /** "Simulate" button. */
    virtual void onSimulate() = 0;
};

class Plugin;
void loadVcrPlugin(Plugin& plug);

#endif
