/**
  *  \file client/widgets/expformat.h
  *  \brief WExportFormatControl widget
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_EXPFORMAT_H
#define PCC_V2_CLIENT_WIDGETS_EXPFORMAT_H

#include "client/wtile.h"
#include "cpluslib/holder.h"

class Stream;
class IntContext;
class AnswerProvider;
class IntExportFieldList;

/** Export format controls. This widget allows the user to select a file format
    for export. It also contains a method doExport() to invoke the selected
    export function. */
class WExportFormatControl : public WTile {
    // Data:
    enum Type {
        tText,
        tTable,
        tCommaSV,
        tTabSV,
        tSemicolonSV,
        tJSON,
        tDBF
    };
    Type type;
    int charset_index;

    // Widgets & Layout:
    ObjectHolder h;
    int left_x, right_x, right_wi;

 public:
    WExportFormatControl();
    ~WExportFormatControl();

    bool handleEvent(const UIEvent& event, bool second_pass);
    void getLayoutInfo(LayoutInfo& info);
    void drawData(GfxCanvas& can);

    void doExport(Stream& file, IntContext* array, AnswerProvider& filter, IntExportFieldList& job);
    string_t getRecommendedFileExtension();

 private:
    void init();
    void computeLayout();

    void changeType();
    void changeCharset();
};

#endif
