/**
  *  \file client/widgets/optiongrid.h
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_OPTIONGRID_H
#define PCC_V2_CLIENT_WIDGETS_OPTIONGRID_H

#include "ui/ui.h"
#include "cpluslib/ptrvector.h"

/** Option grid.
    Implements a list of button/label/values used in option dialogs.
    Users can click the buttons to cause a sig_click callback. */
class WOptionGrid : public UIWidget {
 public:
    class Item;

    /** Reference to an item.
        Wraps a pointer to an item of the list, and offers operations on it.
        The pointer can be null.
        The idea is to use code like "find(id).setValue(...)" to modify an item,
        without having to deal with the option grid not containing a value today. */
    class Ref {
     public:
        Ref(Item* pItem = 0)
            : pItem(pItem)
            { }
        Ref& setFont(int font);
        Ref& setValue(string_t str);
        Ref& setValue(const char* str);
        Ref& setLabel(string_t str);
        Ref& enable(bool flag);

     private:
        Item* pItem;
    };

    WOptionGrid(int leftWidth, int rightWidth);
    ~WOptionGrid();

    Ref addItem(int id, char key, string_t label);
    Ref find(int id);

    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);
    bool handleEvent(const UIEvent& event, bool second_pass);

    Signal1<int> sig_click;

 private:
    int leftWidth;
    int rightWidth;
    ptr_vector<Item> items;
};

#endif
