/**
  *  \file game/playerset.h
  *  \brief Player-Indexed Data Types
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_PLAYERSET_H
#define PCC_V2_GAME_PLAYERSET_H

#include "cpluslib/smallset.h"
#include "cpluslib/assert.h"
#include "cpluslib/string.h"

/** Set of players. */
typedef SmallSet<int> GPlayerSet;

/** 2-D bit array of players. */
class GPlayerBitMatrix {
    GPlayerSet data[12];
 public:
    GPlayerBitMatrix();

    bool get(int subj, int obj) const;
    void set(int subj, int obj, bool value);

    void clear();

    GPlayerSet getRow(int subj) const;
};

/** Array indexed by player. */
template<typename T>
class GPlayerArray {
    T data[13];
 public:
    T&          operator[](int pl);
    const T&    operator[](int pl) const;
    void        setAll(T n);

    static bool isValidIndex(int pl);
};

string_t formatPlayerSet(GPlayerSet set);

/***************************** Implementation ****************************/

template<typename T>
T&
GPlayerArray<T>::operator[](int pl)
{
    ASSERT(isValidIndex(pl));
    return data[pl];
}

template<typename T>
const T&
GPlayerArray<T>::operator[](int pl) const
{
    ASSERT(isValidIndex(pl));
    return data[pl];
}

template<typename T>
void
GPlayerArray<T>::setAll(T n)
{
    for (int i = 0; i < 13; ++i)
        data[i] = n;
}

template<typename T>
inline bool
GPlayerArray<T>::isValidIndex(int pl)
{
    return pl >= 0 && pl <= 12;
}

#endif
