/**
  *  \file reshack/select.h
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_RESHACK_SELECT_H
#define PCC_V2_RESHACK_SELECT_H

#include <vector>
#include "ui/ui.h"
#include "cpluslib/ptrvector.h"
#include "reshack/tools.h"

class RHPainter;

class RHModeSelector : public UIWidget {
 protected:
    virtual bool isActive(int slot) = 0;
    virtual bool isUsable(int slot) = 0;
    virtual void activate(int slot) = 0;
    virtual string_t getName(int slot) = 0;
    virtual int getNumSlots() = 0;
    virtual int getSlotFromKey(UIKey k) = 0;
 public:
    RHModeSelector();
    ~RHModeSelector();

    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);
    void getLayoutInfo(LayoutInfo& info);
};

class RHToolSelector : public RHModeSelector {
    ptr_vector<RHTool> tools;
    std::vector<UIKey> keys;
    RHPainter& painter;

 public:
    RHToolSelector(RHPainter& painter);
    ~RHToolSelector();

    void addNewTool(UIKey key, RHTool* t);

    bool isActive(int slot);
    bool isUsable(int slot);
    void activate(int slot);
    string_t getName(int slot);
    int getNumSlots();
    int getSlotFromKey(UIKey k);
};

class RHZoomSelector : public RHModeSelector {
    RHPainter& painter;
    const int nslots;

 public:
    RHZoomSelector(RHPainter& painter, int nslots);
    ~RHZoomSelector();

    bool isActive(int slot);
    bool isUsable(int slot);
    void activate(int slot);
    string_t getName(int slot);
    int getNumSlots();
    int getSlotFromKey(UIKey k);
};

#endif
