/**
  *  \file ui/widgets/icongrid.h
  *  \brief UIIconGrid widget
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_ICONGRID_H
#define PCC_V2_UI_WIDGETS_ICONGRID_H

#include "ui/ui.h"

/** Icon Grid widget. This displays a set of icons of identical size.

    Icons are identified by X/Y coordinates. For simplicity, icons can
    also be identified by a number generated by counting row-wise.

    The widget allows the user to move around on the displayed list. 
    Derived classes must override the drawIcon method to implement
    actual display of the icons. */
class UIIconGrid : public UIWidget {
 public:
    UIIconGrid(GfxPoint iconSize, int width, int height, int id = 0);
    ~UIIconGrid();

    virtual void drawIcon(GfxCanvas& can, const GfxRect& pos, int x, int y, FocusState state) = 0;

    bool handleEvent(const UIEvent& event, bool second_pass);
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& info);

    int getCurrentX() const;
    int getCurrentY() const;
    int getCurrentPos() const;

    int getNumColumns() const;
    int getNumLines() const;

    void setCurrentPos(int x, int y);
    void setCurrentPos(int n);

    /** Raised when the current position changes. */
    Signal0 sig_moved;

 protected:
    void setGeometry(GfxPoint iconSize, int width, int height);

 private:
    GfxPoint iconSize;
    int width;
    int height;
    int x;
    int y;
    int top;
};

/** Get current X coordinate (column). */
inline int
UIIconGrid::getCurrentX() const
{
    return x;
}

/** Get current Y coordinate (line). */
inline int
UIIconGrid::getCurrentY() const
{
    return y;
}

/** Get current linear position. */
inline int
UIIconGrid::getCurrentPos() const
{
    return x + y*width;
}

/** Get number of columns. */
inline int
UIIconGrid::getNumColumns() const
{
    return width;
}

/** Get number of lines. */
inline int
UIIconGrid::getNumLines() const
{
    return height;
}

#endif
